==> nextcloud-18.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/he.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "שיתף/שיתפה אתך",
    "Nothing shared with you yet" : "עדיין לא שיתפו אתך דבר",
    "Files and folders others share with you will show up here" : "קבצים ותיקיות שאחרים שיתפו אתך יוצגו כאן",
    "Shared with others" : "משותף עם אחרים",
    "Nothing shared yet" : "עדיין לא שותף דבר",
    "Files and folders you share will show up here" : "קבצים ותיקיות ששיתפת יוצגו כאן",
    "Shared by link" : "משותף עם קישור",
    "No shared links" : "אין קישורים משותפים",
    "Files and folders you share by link will show up here" : "קבצים ותיקיות ששיתפת עם קישור יוצגו כאן",
    "Deleted shares" : "שיתופים שנמחקו",
    "No deleted shares" : "אין שיתופים שנמחקו",
    "Shares you deleted will show up here" : "שיתופים שמחקת יופיעו כאן",
    "Pending shares" : "שיתופים ממתינים",
    "No pending shares" : "אין שיתופים ממתינים",
    "Shares you have received but not confirmed will show up here" : "שיתופים שקיבלת אבל לא אישרת יופיעו כאן",
    "Shares" : "שיתופים",
    "No shares" : "אין שיתופים",
    "Shares will show up here" : "שיתופים יופיעו כאן",
    "Restore" : "שחזור",
    "Restore share" : "שחזור שיתוף",
    "Something happened. Unable to restore the share." : "משהו התרחש. לא ניתן לשחזר את השיתוף.",
    "Accept share" : "קבלת השיתוף",
    "Something happened. Unable to accept the share." : "משהו התרחש. לא ניתן לשחזר את השיתוף.",
    "Reject share" : "דחיית השיתוף",
    "Something happened. Unable to reject the share." : "משהו התרחש. לא ניתן לדחות את השיתוף.",
    "error" : "שגיאה",
    "This will stop your current uploads." : "פעולה זו תעצור את השליחות הנוכחיות שלך.",
    "Move or copy" : "העברה או העתקה",
    "Download" : "הורדה",
    "Delete" : "מחיקה",
    "You can upload into this folder" : "ניתן להעלות לתיקייה זו",
    "Terms of service" : "תנאי שירות",
    "No compatible server found at {remote}" : "לא נמצא שרת תואם בכתובת {remote}",
    "Invalid server URL" : "כתובת השרת שגויה",
    "Failed to add the public link to your Nextcloud" : "אירע כשל בהוספת קישור ציבורי ל־Nextcloud שלך",
    "No expiration date set" : "לא הוגדר מועד תפוגה",
    "Shared by" : "שותף על־ידי",
    "File shares" : "שיתופי קבצים",
    "Downloaded via public link" : "הורד על בסיס קישור ציבורי",
    "Downloaded by {email}" : "הורד על ידי {email}",
    "{file} downloaded via public link" : "{file} התקבל דרך קישור ציבורי",
    "{email} downloaded {file}" : "{file} הורד על ידי {email}",
    "Shared with group {group}" : "שותף עם הקבוצה {group}",
    "Removed share for group {group}" : "הוסר שיתוף עם הקבוצה {group}",
    "{actor} shared with group {group}" : "שותף עם הקבוצה {group} על ידי {actor}",
    "{actor} removed share for group {group}" : "הוסר השיתוף עם הקבוצה {group} על ידי {actor}",
    "Share for group {group} expired" : "תוקף השיתוף עם הקבוצה {group} פג",
    "You shared {file} with group {group}" : "שיתפת {file} עם הקבוצה {group}",
    "You removed group {group} from {file}" : "הסרת את הקבוצה {group} מהקובץ {file}",
    "{actor} shared {file} with group {group}" : "הקובץ {file} שותף עם הקבוצה {group} על ידי {actor}",
    "{actor} removed group {group} from {file}" : "הקבוצה {group} הוסרה מהשיתוף {file} על ידי {actor}",
    "Share for file {file} with group {group} expired" : "תוקף שיתוף הקובץ {file} עם הקבוצה {group} פג",
    "Shared as public link" : "שותף כקישור ציבורי",
    "Removed public link" : "הסיר/ה קישור ציבורי",
    "Public link expired" : "קישור ציבורי פג תוקף",
    "{actor} shared as public link" : "שותף כקישור ציבורי על ידי {actor}",
    "{actor} removed public link" : "הקישור הציבורי הוסר על ידי {actor}",
    "Public link of {actor} expired" : "תוקף הקישור הציבורי של {actor} פג",
    "You shared {file} as public link" : "שיתפת את {file} כקישור ציבורי",
    "You removed public link for {file}" : "הסרת קישור ציבורי עבור {file}",
    "Public link expired for {file}" : "תוקף הקישור הציבורי עבור {file} פג",
    "{actor} shared {file} as public link" : "{file} שותף כקישור ציבורי על ידי {actor}",
    "{actor} removed public link for {file}" : "הקישור הציבורי עבור {file} הוסר על ידי {actor}",
    "Public link of {actor} for {file} expired" : "תוקף הקישור הציבורי של {actor} עבור {file} פג",
    "{user} accepted the remote share" : "השיתוף המרוחק התקבל על ידי {user}",
    "{user} declined the remote share" : "השיתוף המרוחק נדחה על ידי {user}",
    "You received a new remote share {file} from {user}" : "קיבלת שיתוף מרוחק חדש {file} מאת",
    "{user} accepted the remote share of {file}" : "השיתוף המרוחק של {file} התקבל על ידי {user}",
    "{user} declined the remote share of {file}" : "השיתוף המרוחק של {file} נדחה על ידי {user}",
    "Shared with {user}" : "שותף עם {user}",
    "Removed share for {user}" : "הוסר השיתוף עבור {user}",
    "You removed yourself" : "הסרת את עצמך",
    "{actor} shared with {user}" : "שותף עם {user} על ידי {actor}",
    "{actor} removed share for {user}" : "השיתוף עבור {user} הוסר על ידי {actor}",
    "Shared by {actor}" : "שותף על ידי {actor}",
    "{actor} removed share" : "שיתוף הוסר על ידי {actor}",
    "Share expired" : "תוקף השיתוף פג",
    "You shared {file} with {user}" : "שיתפת את {file} עם {user}",
    "You removed {user} from {file}" : "הסרת את {user} מהקובץ {file}",
    "You removed yourself from {file}" : "הסרת את עצמך מהקובץ {file}",
    "{actor} shared {file} with {user}" : "{file} שותף עם {user} על ידי {actor}",
    "{actor} removed you from the share named {file}" : "הוסרת מהשיתוף בשם {file} על ידי {actor}",
    "Share for file {file} with {user} expired" : "תוקף שיתוף הקובץ {file} עם {user} פג",
    "Share for file {file} expired" : "שיתוף הקובץ {file} פג",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "קובץ או תיקייה ששותפו בדוא״ל או דרך קישור ציבורי <strong>הורדו</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "קובץ או תיקייה שותפו מ- <strong>שרת אחר</strong>",
    "A file or folder has been <strong>shared</strong>" : "קובץ או תיקייה <strong>שותפו<strong/>",
    "Wrong share ID, share doesn't exist" : "מספר זיהוי שיתוף שגוי, שיתוף אינו קיים",
    "Could not delete share" : "לא ניתן היה למחוק את השיתוף",
    "Please specify a file or folder path" : "יש לספק נתיב לקובץ או תיקייה",
    "Wrong path, file/folder doesn't exist" : "נתיב שגוי, קובץ/תיקייה אינם קיימים",
    "Could not create share" : "לא ניתן ליצור שיתוף",
    "invalid permissions" : "הרשאות שגויות",
    "Please specify a valid user" : "יש לספק משתמש חוקי",
    "Group sharing is disabled by the administrator" : "שיתוף קבוצתי מנוטרל על ידי המנהל",
    "Please specify a valid group" : "יש לספק קבוצה חוקית",
    "Public link sharing is disabled by the administrator" : "שיתוף ציבורי מנוטרל על ידי המנהל",
    "Public upload disabled by the administrator" : "שיתוף ציבורי מנוטרל על ידי המנהל",
    "Public upload is only possible for publicly shared folders" : "העלאה ציבורית אפשרית רק אל תיקיות משותפות ציבוריות",
    "Invalid date, date format must be YYYY-MM-DD" : "תאריך לא חוקי, תבנית התאריך חייבת להיות YYYY-MM-DD",
    "You cannot share to a Circle if the app is not enabled" : "לא ניתן לשתף למעגל אם היישומון לא מופעל",
    "Please specify a valid circle" : "נא לציין מעגל תקני",
    "Unknown share type" : "סוג שיתוף אינו מוכר",
    "Not a directory" : "אינה תיקייה",
    "Could not lock path" : "לא ניתן היה לנעול נתיב",
    "Wrong or no update parameter given" : "משתנה עדכון שניתן שגוי או לא קיים",
    "Can't change permissions for public share links" : "לא ניתן לשנות הרשאות לקישורי שיתוף ציבוריים",
    "shared by %s" : "שותף על ידי %s",
    "Download all files" : "הורדת כל הקבצים",
    "Direct link" : "קישור ישיר",
    "Add to your Nextcloud" : "הוספה ל־Nextcloud שלך",
    "Share API is disabled" : "שיתוף API מנוטרל",
    "File sharing" : "שיתוף קבצים",
    "Accept" : "קבלה",
    "Reject" : "דחייה",
    "Sharing" : "שיתוף",
    "Allow editing" : "לאפשר עריכה",
    "Allow resharing" : "לאפשר שיתוף מחדש",
    "Expiration date enforced" : "נאכף מועד תפוגה",
    "Set expiration date" : "הגדרת תאריך תפוגה",
    "Note to recipient" : "מסר לנמען",
    "Unshare" : "ביטול שיתוף",
    "group" : "קבוצה",
    "conversation" : "דיון",
    "remote" : "מרוחק",
    "remote group" : "קבוצה מרוחקת",
    "guest" : "אורח",
    "Link copied" : "הקישור הועתק",
    "Copy to clipboard" : "העתקה ללוח הגזירים",
    "Only works for users with access to this folder" : "עובד רק עבוד משתמשים עם גישה לתיקייה הזו",
    "Password protection" : "Password protection",
    "Enter a password" : "נא להקליד ססמה",
    "Cancel" : "ביטול",
    "Read only" : "קריאה בלבד",
    "Allow upload and editing" : "לאפשר העלאה ועריכה",
    "File drop (upload only)" : "השלכת קבצים (העלאה בלבד)",
    "Hide download" : "הסתרת הורדה",
    "Password protect" : "הגנה בססמה",
    "Add another link" : "הוספת קישור נוסף",
    "Share link" : "שיתוף קישור",
    "Resharing is not allowed" : "שיתוף מחדש אסור",
    "Search globally" : "חיפוש גלובלי",
    "Link to a file" : "קישור לקובץ",
    "Shared" : "משותף",
    "Share" : "שיתוף",
    "Shared with" : "משותף עם",
    "Shared with you and the group {group} by {owner}" : "שותף אתך ועם הקבוצה {group} על ידי {owner}",
    "Shared with you and {circle} by {owner}" : "משותף אתך ועם {circle} על ידי {owner}",
    "Shared with you by {owner}" : "שותף אתך על ידי {owner}",
    "No entries found in this folder" : "לא נמצאו כניסות לתיקייה זו",
    "Name" : "שם",
    "Share time" : "זמן שיתוף",
    "Expiration date" : "מועד תפוגה",
    "Sorry, this link doesn’t seem to work anymore." : "מצטערים, לא נראה שקישור זה עובד יותר. ",
    "Reasons might be:" : "הסיבות יכולות להיות:",
    "the item was removed" : "הפריט הוסר",
    "the link expired" : "הקישור פג תוקף",
    "sharing is disabled" : "השיתוף נוטרל",
    "For more info, please ask the person who sent this link." : "למידע נוסף, יש לפנות לשולח קישור זה.",
    "Share note" : "פתק שיתוף",
    "Toggle grid view" : "החלפת תצוגת טבלה",
    "Download %s" : "הורדה %s",
    "Upload files to %s" : "העלאת קבצים על %s",
    "Note" : "פתק",
    "Select or drop files" : "בחירה או השלכה של קבצים",
    "Uploaded files:" : "קבצים שהועלו:",
    "By uploading files, you agree to the %1$sterms of service%2$s." : "עצם העלאתם של קבצים מביעה את הסכמתך ל%1$sתנאי השירות%2$s.",
    "could not delete share" : "לא ניתן למחוק שיתוף",
    "Uploading files…" : "קבצים מועלים…"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");

==> nextcloud-19.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/he.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "שיתף/שיתפה אתך",
    "Nothing shared with you yet" : "עדיין לא שיתפו אתך דבר",
    "Files and folders others share with you will show up here" : "קבצים ותיקיות שאחרים שיתפו אתך יוצגו כאן",
    "Shared with others" : "משותף עם אחרים",
    "Nothing shared yet" : "עדיין לא שותף דבר",
    "Files and folders you share will show up here" : "קבצים ותיקיות ששיתפת יוצגו כאן",
    "Shared by link" : "משותף עם קישור",
    "No shared links" : "אין קישורים משותפים",
    "Files and folders you share by link will show up here" : "קבצים ותיקיות ששיתפת עם קישור יוצגו כאן",
    "Deleted shares" : "שיתופים שנמחקו",
    "No deleted shares" : "אין שיתופים שנמחקו",
    "Shares you deleted will show up here" : "שיתופים שמחקת יופיעו כאן",
    "Pending shares" : "שיתופים ממתינים",
    "No pending shares" : "אין שיתופים ממתינים",
    "Shares you have received but not confirmed will show up here" : "שיתופים שקיבלת אבל לא אישרת יופיעו כאן",
    "Shares" : "שיתופים",
    "No shares" : "אין שיתופים",
    "Shares will show up here" : "שיתופים יופיעו כאן",
    "Restore" : "שחזור",
    "Restore share" : "שחזור שיתוף",
    "Something happened. Unable to restore the share." : "משהו התרחש. לא ניתן לשחזר את השיתוף.",
    "Accept share" : "קבלת השיתוף",
    "Something happened. Unable to accept the share." : "משהו התרחש. לא ניתן לשחזר את השיתוף.",
    "Reject share" : "דחיית השיתוף",
    "Something happened. Unable to reject the share." : "משהו התרחש. לא ניתן לדחות את השיתוף.",
    "Waiting…" : "בהמתנה…",
    "error" : "שגיאה",
    "finished" : "הסתיים",
    "This will stop your current uploads." : "פעולה זו תעצור את השליחות הנוכחיות שלך.",
    "Move or copy" : "העברה או העתקה",
    "Download" : "הורדה",
    "Delete" : "מחיקה",
    "You can upload into this folder" : "ניתן להעלות לתיקייה זו",
    "Terms of service" : "תנאי שירות",
    "No compatible server found at {remote}" : "לא נמצא שרת תואם בכתובת {remote}",
    "Invalid server URL" : "כתובת השרת שגויה",
    "Failed to add the public link to your Nextcloud" : "אירע כשל בהוספת קישור ציבורי ל־Nextcloud שלך",
    "No expiration date set" : "לא הוגדר מועד תפוגה",
    "Shared by" : "שותף על־ידי",
    "File shares" : "שיתופי קבצים",
    "Downloaded via public link" : "הורד על בסיס קישור ציבורי",
    "Downloaded by {email}" : "הורד על ידי {email}",
    "{file} downloaded via public link" : "{file} התקבל דרך קישור ציבורי",
    "{email} downloaded {file}" : "{file} הורד על ידי {email}",
    "Shared with group {group}" : "שותף עם הקבוצה {group}",
    "Removed share for group {group}" : "הוסר שיתוף עם הקבוצה {group}",
    "{actor} shared with group {group}" : "שותף עם הקבוצה {group} על ידי {actor}",
    "{actor} removed share for group {group}" : "הוסר השיתוף עם הקבוצה {group} על ידי {actor}",
    "Share for group {group} expired" : "תוקף השיתוף עם הקבוצה {group} פג",
    "You shared {file} with group {group}" : "שיתפת {file} עם הקבוצה {group}",
    "You removed group {group} from {file}" : "הסרת את הקבוצה {group} מהקובץ {file}",
    "{actor} shared {file} with group {group}" : "הקובץ {file} שותף עם הקבוצה {group} על ידי {actor}",
    "{actor} removed group {group} from {file}" : "הקבוצה {group} הוסרה מהשיתוף {file} על ידי {actor}",
    "Share for file {file} with group {group} expired" : "תוקף שיתוף הקובץ {file} עם הקבוצה {group} פג",
    "Shared as public link" : "שותף כקישור ציבורי",
    "Removed public link" : "הסיר/ה קישור ציבורי",
    "Public link expired" : "קישור ציבורי פג תוקף",
    "{actor} shared as public link" : "שותף כקישור ציבורי על ידי {actor}",
    "{actor} removed public link" : "הקישור הציבורי הוסר על ידי {actor}",
    "Public link of {actor} expired" : "תוקף הקישור הציבורי של {actor} פג",
    "You shared {file} as public link" : "שיתפת את {file} כקישור ציבורי",
    "You removed public link for {file}" : "הסרת קישור ציבורי עבור {file}",
    "Public link expired for {file}" : "תוקף הקישור הציבורי עבור {file} פג",
    "{actor} shared {file} as public link" : "{file} שותף כקישור ציבורי על ידי {actor}",
    "{actor} removed public link for {file}" : "הקישור הציבורי עבור {file} הוסר על ידי {actor}",
    "Public link of {actor} for {file} expired" : "תוקף הקישור הציבורי של {actor} עבור {file} פג",
    "{user} accepted the remote share" : "השיתוף המרוחק התקבל על ידי {user}",
    "{user} declined the remote share" : "השיתוף המרוחק נדחה על ידי {user}",
    "You received a new remote share {file} from {user}" : "קיבלת שיתוף מרוחק חדש {file} מאת",
    "{user} accepted the remote share of {file}" : "השיתוף המרוחק של {file} התקבל על ידי {user}",
    "{user} declined the remote share of {file}" : "השיתוף המרוחק של {file} נדחה על ידי {user}",
    "Shared with {user}" : "שותף עם {user}",
    "Removed share for {user}" : "הוסר השיתוף עבור {user}",
    "You removed yourself" : "הסרת את עצמך",
    "{actor} removed themselves" : "{actor} הסירו את עצמם",
    "{actor} shared with {user}" : "שותף עם {user} על ידי {actor}",
    "{actor} removed share for {user}" : "השיתוף עבור {user} הוסר על ידי {actor}",
    "Shared by {actor}" : "שותף על ידי {actor}",
    "{actor} removed share" : "שיתוף הוסר על ידי {actor}",
    "Share for {user} expired" : "תוקף השיתוף של {user} פג",
    "Share expired" : "תוקף השיתוף פג",
    "You shared {file} with {user}" : "שיתפת את {file} עם {user}",
    "You removed {user} from {file}" : "הסרת את {user} מהקובץ {file}",
    "You removed yourself from {file}" : "הסרת את עצמך מהקובץ {file}",
    "{actor} shared {file} with {user}" : "{file} שותף עם {user} על ידי {actor}",
    "{actor} removed you from the share named {file}" : "הוסרת מהשיתוף בשם {file} על ידי {actor}",
    "Share for file {file} with {user} expired" : "תוקף שיתוף הקובץ {file} עם {user} פג",
    "Share for file {file} expired" : "שיתוף הקובץ {file} פג",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "קובץ או תיקייה ששותפו בדוא״ל או דרך קישור ציבורי <strong>הורדו</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "קובץ או תיקייה שותפו מ- <strong>שרת אחר</strong>",
    "A file or folder has been <strong>shared</strong>" : "קובץ או תיקייה <strong>שותפו<strong/>",
    "Shared link" : "שותף קישור",
    "Wrong share ID, share doesn't exist" : "מספר זיהוי שיתוף שגוי, שיתוף אינו קיים",
    "Could not delete share" : "לא ניתן היה למחוק את השיתוף",
    "Please specify a file or folder path" : "יש לספק נתיב לקובץ או תיקייה",
    "Wrong path, file/folder doesn't exist" : "נתיב שגוי, קובץ/תיקייה אינם קיימים",
    "Could not create share" : "לא ניתן ליצור שיתוף",
    "invalid permissions" : "הרשאות שגויות",
    "Please specify a valid user" : "יש לספק משתמש חוקי",
    "Group sharing is disabled by the administrator" : "שיתוף קבוצתי מנוטרל על ידי המנהל",
    "Please specify a valid group" : "יש לספק קבוצה חוקית",
    "Public link sharing is disabled by the administrator" : "שיתוף ציבורי מנוטרל על ידי המנהל",
    "Public upload disabled by the administrator" : "שיתוף ציבורי מנוטרל על ידי המנהל",
    "Public upload is only possible for publicly shared folders" : "העלאה ציבורית אפשרית רק אל תיקיות משותפות ציבוריות",
    "Invalid date, date format must be YYYY-MM-DD" : "תאריך לא חוקי, תבנית התאריך חייבת להיות YYYY-MM-DD",
    "You cannot share to a Circle if the app is not enabled" : "לא ניתן לשתף למעגל אם היישומון לא מופעל",
    "Please specify a valid circle" : "נא לציין מעגל תקני",
    "Unknown share type" : "סוג שיתוף אינו מוכר",
    "Not a directory" : "אינה תיקייה",
    "Could not lock path" : "לא ניתן היה לנעול נתיב",
    "Wrong or no update parameter given" : "משתנה עדכון שניתן שגוי או לא קיים",
    "Can't change permissions for public share links" : "לא ניתן לשנות הרשאות לקישורי שיתוף ציבוריים",
    "shared by %s" : "שותף על ידי %s",
    "Download all files" : "הורדת כל הקבצים",
    "Direct link" : "קישור ישיר",
    "Add to your Nextcloud" : "הוספה ל־Nextcloud שלך",
    "Share API is disabled" : "שיתוף API מנוטרל",
    "File sharing" : "שיתוף קבצים",
    "Share will expire tomorrow" : "תוקף השיתוף יפוג מחר",
    "One or more of your shares will expire tomorrow" : "תפוגתם של שיתוף אחד או יותר יפוג מחר",
    "Accept" : "קבלה",
    "Reject" : "דחייה",
    "Sharing" : "שיתוף",
    "Accept user and group shares by default" : "לקבל את שיתופי המשתמשים והקבוצות כבררת מחדל",
    "Allow editing" : "לאפשר עריכה",
    "Allow creating" : "לאפשר יצירה",
    "Allow deleting" : "לאפשר מחיקה",
    "Allow resharing" : "לאפשר שיתוף מחדש",
    "Expiration date enforced" : "נאכף מועד תפוגה",
    "Set expiration date" : "הגדרת תאריך תפוגה",
    "Enter a date" : "נא למלא תאריך",
    "Note to recipient" : "מסר לנמען",
    "Unshare" : "ביטול שיתוף",
    "group" : "קבוצה",
    "conversation" : "דיון",
    "remote" : "מרוחק",
    "remote group" : "קבוצה מרוחקת",
    "guest" : "אורח",
    "Shared with the group {user} by {owner}" : "שותף עם הקבוצה {user} על ידי {owner}",
    "Shared with the conversation {user} by {owner}" : "שותף עם הדיון {user} על ידי {owner}",
    "Shared with {user} by {owner}" : "שותף עם {user} על ידי {owner}",
    "Added by {initiator}" : "נוסף על ידי {initiator}",
    "Internal link" : "קישור פנימי",
    "Link copied" : "הקישור הועתק",
    "Cannot copy, please copy the link manually" : "לא ניתן להעתיק, נא להעתיק את הקישור ידנית",
    "Copy to clipboard" : "העתקה ללוח הגזירים",
    "Only works for users with access to this folder" : "עובד רק עבור משתמשים עם גישה לתיקייה הזו",
    "Only works for users with access to this file" : "עובד רק עבור משתמשים עם גישה לקובץ הזה",
    "Please enter the following required information before creating the share" : "נא למלא את הפרטים הנחוצים הבאים בטרם יצירת השיתוף",
    "Password protection (enforced)" : "הגנה בססמה (נאכף)",
    "Password protection" : "Password protection",
    "Enter a password" : "נא להקליד ססמה",
    "Expiration date (enforced)" : "תאריך תפוגה (נאכף)",
    "Cancel" : "ביטול",
    "Read only" : "קריאה בלבד",
    "Allow upload and editing" : "לאפשר העלאה ועריכה",
    "File drop (upload only)" : "השלכת קבצים (העלאה בלבד)",
    "Hide download" : "הסתרת הורדה",
    "Password protect" : "הגנה בססמה",
    "Video verification" : "אימות וידאו",
    "Enter a note for the share recipient" : "נא להוסיף הערה למקבלי השיתוף",
    "Add another link" : "הוספת קישור נוסף",
    "Create a new share link" : "יצירת קישור שיתוף חדש",
    "Shared via link by {initiator}" : "שותף דרך קישור על ידי {initiator}",
    "Share link" : "שיתוף קישור",
    "Error, please enter proper password and/or expiration date" : "שגיאה, נא למלא ססמה ו/או תאריך תפוגה כראוי",
    "No recommendations. Start typing." : "אין המלצות. נא להתחיל להקליד.",
    "Resharing is not allowed" : "שיתוף מחדש אסור",
    "Name or email address …" : "שם או כתובת דוא״ל…",
    "Name or federated cloud ID …" : "שם או מזהה ענן מאוגד…",
    "Name, federated cloud ID or email address …" : "שם, מזהה ענן מאוגד או כתובת דוא״ל…",
    "Name …" : "שם…",
    "Searching …" : "מתבצע חיפוש…",
    "No elements found." : "לא נמצאו רכיבים.",
    "Search globally" : "חיפוש גלובלי",
    "on {server}" : "על גבי {server}",
    "Others with access" : "נוספים עם גישה",
    "No other users with access found" : "לא נמצאו משתמשים נוספים עם גישה",
    "Toggle list of others with access to this directory" : "החלפת מצב הנוספים עם גישה לתיקייה הזאת",
    "Toggle list of others with access to this file" : "החלפת מצב הנוספים עם גישה לקובץ הזה",
    "Unable to fetch inherited shares" : "לא ניתן לקבל את השיתופים שנורשו",
    "Unable to load the shares list" : "לא ניתן לטעון את רשימת השיתופים",
    "Expires {relativetime}" : "תפוגה: {relativetime}",
    "this share just expired." : "תוקף השיתוף פג זה עתה.",
    "Link to a file" : "קישור לקובץ",
    "Error creating the share" : "יצירת השיתוף נכשלה",
    "Shared" : "משותף",
    "Share" : "שיתוף",
    "Shared with" : "משותף עם",
    "Shared with you and the group {group} by {owner}" : "שותף אתך ועם הקבוצה {group} על ידי {owner}",
    "Shared with you and {circle} by {owner}" : "משותף אתך ועם {circle} על ידי {owner}",
    "Shared with you and the conversation {conversation} by {owner}" : "שותף אתך והדיון {conversation} על ידי {owner}",
    "Shared with you in a conversation by {owner}" : "שותף אתך בדיון על ידי {owner}",
    "Shared with you by {owner}" : "שותף אתך על ידי {owner}",
    "No entries found in this folder" : "לא נמצאו כניסות לתיקייה זו",
    "Name" : "שם",
    "Share time" : "זמן שיתוף",
    "Expiration date" : "מועד תפוגה",
    "Sorry, this link doesn’t seem to work anymore." : "מצטערים, לא נראה שקישור זה עובד יותר. ",
    "Reasons might be:" : "הסיבות יכולות להיות:",
    "the item was removed" : "הפריט הוסר",
    "the link expired" : "הקישור פג תוקף",
    "sharing is disabled" : "השיתוף נוטרל",
    "For more info, please ask the person who sent this link." : "למידע נוסף, יש לפנות לשולח קישור זה.",
    "Share note" : "פתק שיתוף",
    "Toggle grid view" : "החלפת תצוגת טבלה",
    "Download %s" : "הורדה %s",
    "Upload files to %s" : "העלאת קבצים על %s",
    "Note" : "פתק",
    "Select or drop files" : "בחירה או השלכה של קבצים",
    "Uploading files" : "מועלים קבצים",
    "Uploaded files:" : "קבצים שהועלו:",
    "By uploading files, you agree to the %1$sterms of service%2$s." : "עצם העלאתם של קבצים מביעה את הסכמתך ל%1$sתנאי השירות%2$s.",
    "could not delete share" : "לא ניתן למחוק שיתוף",
    "Uploading files…" : "קבצים מועלים…"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
